# ifndef yyMakeOn
# define yyMakeOn

# if defined __STDC__ | defined __cplusplus
# define ARGS(parameters)	parameters
# else
# define ARGS(parameters)	()
# endif

# ifndef rbool
# define rbool char
# endif

# include "Tree.h"
# include "Definitions.h"


extern void (* MakeOn_Exit) ARGS ((void));

extern void MakeOn ARGS ((tTree t));

extern void BeginMakeOn ARGS ((void));
extern void CloseMakeOn ARGS ((void));

# endif
